@@ -1,13 +1,12 @@
 use std::{convert::TryInto, fs::File};
 
 use tabled::{Style, Table, Tabled};
-use vach::prelude::*;
+use vach2::prelude::{HeaderConfig, Archive, Flags};
 use bytesize::ByteSize;
 
 use super::CommandTrait;
 use crate::keys::key_names;
 
-
 pub const VERSION: &str = "0.0.1";
 
 /// This command lists the entries in an archive in tabulated form
@@ -17,12 +16,14 @@ impl CommandTrait for Evaluator {
 	fn evaluate(&self, args: &clap::ArgMatches) -> anyhow::Result<()> {
 		let archive_path = match args.value_of(key_names::INPUT) {
 			Some(path) => path,
-			None => anyhow::bail!("Please provide an input archive file using the -i or --input keys!"),
+			None => {
+				anyhow::bail!("Please provide an input archive file using the -i or --input keys!")
+			}
 		};
 
-		let magic: [u8; vach::MAGIC_LENGTH] = match args.value_of(key_names::MAGIC) {
+		let magic: [u8; vach2::MAGIC_LENGTH] = match args.value_of(key_names::MAGIC) {
 			Some(magic) => magic.as_bytes().try_into()?,
-			None => *vach::DEFAULT_MAGIC,
+			None => *vach2::DEFAULT_MAGIC,
 		};
 
 		let file = File::open(archive_path)?;
