@@ -8,8 +8,12 @@ mod utils;
 fn main() {
 	use keys::key_names;
 
+	// Build CLI
 	let keys = keys::build_keys();
 	let app = app::build_app(keys);
+	let commands = commands::build_commands();
+
+	// Start CLI
 	let matches = app.get_matches();
 
 	if matches.is_present(key_names::QUIET) {
@@ -17,14 +21,11 @@ fn main() {
 	};
 
 	let res = match matches.subcommand() {
-		("keypair", Some(mtx)) => commands::KEYPAIR_COMMAND.evaluate(mtx),
-		("split", Some(mtx)) => commands::SPLIT_COMMAND.evaluate(mtx),
-		("verify", Some(mtx)) => commands::VERIFY_COMMAND.evaluate(mtx),
-		("list", Some(mtx)) => commands::LIST_COMMAND.evaluate(mtx),
-		("pack", Some(mtx)) => commands::PACK_COMMAND.evaluate(mtx),
-		("unpack", Some(mtx)) => commands::UNPACK_COMMAND.evaluate(mtx),
-		("", _) => Ok(println!("vach-cli: Run `vach --help` for usage")),
-		(cmd, _) => Err(anyhow::anyhow!("[Unknown Command]: {}", cmd)),
+		Some((key, mtx)) => commands.get(key).unwrap().evaluate(mtx),
+		None => {
+			log::info!("vach-cli: Run `vach --help` for usage");
+			Ok(())
+		}
 	};
 
 	if let Err(err) = res {
